@@ -1,10 +1,7 @@
 import React from 'react';
 import PropTypes from 'prop-types';
-import FormLabel from '../../components/style/form-label';
-import Button from '../../components/style/button';
-
-var tableStyle = { width: "100%", borderSpacing: "2px 0", marginBottom: "2px" };
-var firstTdStyle = { width: '6em' };
+import { FormLabel, Button } from '../../components/style/export';
+import PropertyStyle from './shared-property-style';
 
 export default function PropertyToggle(_ref) {
   var value = _ref.value,
@@ -28,7 +25,7 @@ export default function PropertyToggle(_ref) {
 
   return React.createElement(
     'table',
-    { className: 'PropertyToggle', style: tableStyle },
+    { className: 'PropertyToggle', style: PropertyStyle.tableStyle },
     React.createElement(
       'tbody',
       null,
@@ -37,7 +34,7 @@ export default function PropertyToggle(_ref) {
         null,
         React.createElement(
           'td',
-          { style: firstTdStyle },
+          { style: PropertyStyle.firstTdStyle },
           React.createElement(
             FormLabel,
             null,
