@@ -75,7 +75,7 @@ export default function ItemAttributesEditor(_ref, _ref2) {
             },
             style: inputStyle,
             state: state,
-            configs: { precision: 2 }
+            precision: 2
           }, rest))
         )
       ),
@@ -97,7 +97,7 @@ export default function ItemAttributesEditor(_ref, _ref2) {
             },
             style: inputStyle,
             state: state,
-            configs: { precision: 2 }
+            precision: 2
           }, rest))
         )
       ),
@@ -119,7 +119,7 @@ export default function ItemAttributesEditor(_ref, _ref2) {
             },
             style: inputStyle,
             state: state,
-            configs: { precision: 2 }
+            precision: 2
           }, rest))
         )
       )
