@@ -10,7 +10,7 @@ var BASE_STYLE = {
   width: "100%",
   padding: "0px 4px",
   fontSize: "13px",
-  color: "#55595c",
+  color: SharedStyle.PRIMARY_COLOR.input,
   backgroundColor: SharedStyle.COLORS.white,
   backgroundImage: "none",
   border: "1px solid rgba(0,0,0,.15)",
