@@ -2,7 +2,6 @@ import * as Three from 'three';
 
 function disposeGeometry(geometry) {
   geometry.dispose();
-  geometry = null;
 }
 
 function disposeTexture(texture) {
@@ -10,7 +9,6 @@ function disposeTexture(texture) {
     return;
   }
   texture.dispose();
-  texture = null;
 }
 
 function disposeMultimaterial(material) {
@@ -28,8 +26,8 @@ function disposeMaterial(material) {
   }
 
   disposeTexture(material.map);
+  material.map = null;
   material.dispose();
-  material = null;
 }
 
 function disposeMesh(mesh) {
@@ -39,17 +37,21 @@ function disposeMesh(mesh) {
   disposeGeometry(mesh.geometry);
   disposeMultimaterial(mesh.material);
   disposeMaterial(mesh.material);
-  mesh = null;
+
+  mesh.geometry = null;
+  mesh.material = null;
 }
 
 export function disposeScene(scene3D) {
   scene3D.traverse(function (child) {
     disposeMesh(child);
+    child = null;
   });
 }
 
 export function disposeObject(object) {
   object.traverse(function (child) {
     disposeMesh(child);
+    child = null;
   });
 }
\ No newline at end of file
