@@ -57,7 +57,7 @@ export var BEGIN_DRAWING_LINE = 'BEGIN_DRAWING_LINE';
 export var UPDATE_DRAWING_LINE = 'UPDATE_DRAWING_LINE';
 export var END_DRAWING_LINE = 'END_DRAWING_LINE';
 export var SELECT_TOOL_DRAWING_HOLE = 'SELECT_TOOL_DRAWING_HOLE';
-export var UPDATE_DRAWING_HOLE = 'UPDATE_DRAWING_HOLE';
+export var UPDATE_DRAWING_HOLE = 'UPDATE_DRAWING_HOLE'; //SHOULD BE SLPITTED IN BEGIN_DRAWING_HOLE AND UPDATE_DRAWING_HOLE
 export var END_DRAWING_HOLE = 'END_DRAWING_HOLE';
 export var BEGIN_DRAGGING_LINE = 'BEGIN_DRAGGING_LINE';
 export var UPDATE_DRAGGING_LINE = 'UPDATE_DRAGGING_LINE';
