@@ -1,5 +1,6 @@
 var localStorage = window.hasOwnProperty('localStorage') ? window.localStorage : false;
 import { loadProject } from '../actions/project-actions';
+import { history } from '../utils//export';
 
 var TIMEOUT_DELAY = 500;
 
@@ -25,12 +26,12 @@ export default function autosave(autosaveKey, delay) {
     store.subscribe(function () {
       if (timeout) clearTimeout(timeout);
       timeout = setTimeout(function () {
-
         var state = stateExtractor(store.getState());
-
-        var scene = state.sceneHistory.last();
-        var json = JSON.stringify(scene.toJS());
-        localStorage.setItem(autosaveKey, json);
+        var scene = state.sceneHistory.last;
+        if (scene) {
+          var _json = JSON.stringify(scene.toJS());
+          localStorage.setItem(autosaveKey, _json);
+        }
       }, delay);
     });
   };
