@@ -4,8 +4,8 @@ import * as MathUtils from './math';
 import * as SnapUtils from './snap';
 import * as SnapSceneUtils from './snap-scene';
 import * as history from './history';
-import * as IDBroker from './id-broker';
 import * as LayerOperations from './layer-operations';
+import IDBroker from './id-broker';
 
 export { GeometryUtils, GraphInnerCycles, MathUtils, SnapUtils, SnapSceneUtils, history, IDBroker, LayerOperations };
 
