@@ -372,9 +372,6 @@ OBJLoader.prototype = {
   },
 
   parse: function parse(text) {
-
-    console.time('OBJLoader');
-
     var state = this._createParserState();
 
     if (text.indexOf('\r\n') !== -1) {
@@ -623,8 +620,6 @@ OBJLoader.prototype = {
       container.add(mesh);
     }
 
-    console.timeEnd('OBJLoader');
-
     return container;
   }
 
