@@ -21,17 +21,14 @@ export default function PanelElementEditor({state}, {projectActions, translator}
       MODE_ROTATING_ITEM, MODE_UPLOADING_IMAGE, MODE_FITTING_IMAGE].includes(mode)) return null;
 
   let componentRenderer = (element, layer) =>
-    <Panel key={element.id} name={translator.t("Properties: [{0}] {1}", element.type, element.id)}>
+    <Panel key={element.id} name={translator.t("Properties: [{0}] {1}", element.type, element.id)} opened={true}>
       <div style={{padding: "5px 15px"}}>
         <ElementEditor element={element} layer={layer} state={state}/>
       </div>
     </Panel>;
 
   let layerRenderer = layer => Seq()
-    .concat(layer.lines)
-    .concat(layer.holes)
-    .concat(layer.areas)
-    .concat(layer.items)
+    .concat(layer.lines, layer.holes, layer.areas, layer.items)
     .filter(element => element.selected)
     .map(element => componentRenderer(element, layer))
     .valueSeq();
