@@ -24,6 +24,7 @@ export const THROW_ERROR = 'THROW_ERROR';
 export const THROW_WARNING = 'THROW_WARNING';
 export const COPY_PROPERTIES = 'COPY_PROPERTIES';
 export const PASTE_PROPERTIES = 'PASTE_PROPERTIES';
+export const PUSH_LAST_SELECTED_CATALOG_ELEMENT_TO_HISTORY = 'PUSH_LAST_SELECTED_CATALOG_ELEMENT_TO_HISTORY';
 
 // ACTIONS viewer2D
 export const SELECT_TOOL_ZOOM_IN = 'SELECT_TOOL_ZOOM_IN';
@@ -56,7 +57,7 @@ export const BEGIN_DRAWING_LINE = 'BEGIN_DRAWING_LINE';
 export const UPDATE_DRAWING_LINE = 'UPDATE_DRAWING_LINE';
 export const END_DRAWING_LINE = 'END_DRAWING_LINE';
 export const SELECT_TOOL_DRAWING_HOLE = 'SELECT_TOOL_DRAWING_HOLE';
-export const UPDATE_DRAWING_HOLE = 'UPDATE_DRAWING_HOLE';
+export const UPDATE_DRAWING_HOLE = 'UPDATE_DRAWING_HOLE'; //SHOULD BE SLPITTED IN BEGIN_DRAWING_HOLE AND UPDATE_DRAWING_HOLE
 export const END_DRAWING_HOLE = 'END_DRAWING_HOLE';
 export const BEGIN_DRAGGING_LINE = 'BEGIN_DRAGGING_LINE';
 export const UPDATE_DRAGGING_LINE = 'UPDATE_DRAGGING_LINE';
@@ -107,7 +108,8 @@ export const PROJECT_ACTIONS = {
   THROW_ERROR,
   THROW_WARNING,
   COPY_PROPERTIES,
-  PASTE_PROPERTIES
+  PASTE_PROPERTIES,
+  PUSH_LAST_SELECTED_CATALOG_ELEMENT_TO_HISTORY
 };
 
 export const VIEWER2D_ACTIONS = {
